@@ -1,6 +1,10 @@
 test_that("minmax label placer", {
   lines <- list(
-    "1" = list(x = c(.5, .75, .5, .25), y = c(.25, .5, .75, .5), id = rep(1, 4)),
+    "1" = list(
+      x = c(.5, .75, .5, .25),
+      y = c(.25, .5, .75, .5),
+      id = rep(1, 4)
+    ),
     "2" = list(x = c(.5, 1, .5, 0), y = c(0, .5, 1, .5), id = rep(1, 4))
   )
 
@@ -22,7 +26,11 @@ test_that("minmax label placer", {
   expect_equal(out$y, c(0.75, 0.25, 1, 0))
   expect_equal(out$theta, rep(0, 4))
 
-  lp <- label_placer_minmax(placement = "rl", rot_adjuster = angle_fixed(1.5), n = 0)
+  lp <- label_placer_minmax(
+    placement = "rl",
+    rot_adjuster = angle_fixed(1.5),
+    n = 0
+  )
   out <- lp(lines, labels_data)
   expect_equal(out$x, c(0.25, 0.75, 0, 1))
   expect_equal(out$y, rep(0.5, 4))
@@ -34,7 +42,6 @@ test_that("minmax label placer", {
 })
 
 
-
 test_that("angle adjustments", {
   theta <- c(-3, -2, -1, 0, 1, 2, 3)
 
@@ -66,7 +73,11 @@ test_that("angle adjustments", {
 
 test_that("none label placer", {
   lines <- list(
-    "1" = list(x = c(.5, .75, .5, .25), y = c(.25, .5, .75, .5), id = rep(1, 4)),
+    "1" = list(
+      x = c(.5, .75, .5, .25),
+      y = c(.25, .5, .75, .5),
+      id = rep(1, 4)
+    ),
     "2" = list(x = c(.5, 1, .5, 0), y = c(0, .5, 1, .5), id = rep(1, 4))
   )
 
@@ -86,7 +97,11 @@ test_that("none label placer", {
 
 test_that("manual label placer", {
   lines <- list(
-    "1" = list(x = c(.5, .75, .5, .25), y = c(.25, .5, .75, .5), id = rep(1, 4)),
+    "1" = list(
+      x = c(.5, .75, .5, .25),
+      y = c(.25, .5, .75, .5),
+      id = rep(1, 4)
+    ),
     "2" = list(x = c(.5, 1, .5, 0), y = c(0, .5, 1, .5), id = rep(1, 4))
   )
 
@@ -102,7 +117,7 @@ test_that("manual label placer", {
     breaks = c("1", "2", "3", "2"),
     x = 1:4,
     y = 4:1,
-    theta = (1:4)-2
+    theta = (1:4) - 2
   )
   out <- lp(lines, labels_data)
   expect_equal(out$index, c(1, 2, 2))
@@ -117,7 +132,11 @@ test_that("manual label placer", {
 # Two isolines id=1
 test_that("middle label placer", {
   lines <- list(
-    "1" = list(x = c(.5, .75, .5, .25), y = c(.25, .5, .75, .5), id = rep(1, 4)),
+    "1" = list(
+      x = c(.5, .75, .5, .25),
+      y = c(.25, .5, .75, .5),
+      id = rep(1, 4)
+    ),
     "2" = list(x = c(.5, 1, .5, 0), y = c(0, .5, 1, .5), id = rep(1, 4))
   )
 
@@ -143,7 +162,11 @@ test_that("middle label placer", {
 # One isoline with two id values (1 and 2)
 test_that("middle label placer", {
   lines <- list(
-    "1" = list(x = c(.5, .75, .5, .25, .5, 1, .5, 0), y = c(.25, .5, .75, .5, 0, .5, 1, .5), id = c(rep(1, 4), rep(2, 4)))
+    "1" = list(
+      x = c(.5, .75, .5, .25, .5, 1, .5, 0),
+      y = c(.25, .5, .75, .5, 0, .5, 1, .5),
+      id = c(rep(1, 4), rep(2, 4))
+    )
   )
 
   labels_data <- data.frame(
